@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: ghc-mod
 version: 5.5.0.0
-id: ghc-mod-5.5.0.0-cd3803be2eae2cdd95b1335a45449d52
-key: ghcmo_Ia4Q7YCao49JkJoYrsKq5m
+id: ghc-mod-5.5.0.0-9d9cb4ea9f7faebb4d1b0886e204dd67
+key: ghcmo_EkXhaPuMiUFFCEuaTTHufU
 license: AGPL-3
 maintainer: Daniel Gröber <dxld@darkboxed.org>
 homepage: http://www.mew.org/~kazu/proj/ghc-mod/
@@ -62,7 +62,7 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/ghc-mod-5.5.0.0
 library-dirs: /usr/lib/ghc-7.10.3/site-local/ghc-mod-5.5.0.0
 data-dir: /usr/share/ghc-mod
-hs-libraries: HSghc-mod-5.5.0.0-Ia4Q7YCao49JkJoYrsKq5m
+hs-libraries: HSghc-mod-5.5.0.0-EkXhaPuMiUFFCEuaTTHufU
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     binary-0.7.5.0-29f7044fa0b12dc5c2dcec897db5c464
@@ -78,10 +78,10 @@ depends:
     ghc-7.10.3-523035ba1e58dc12893f7ef41f66b61d
     ghc-paths-0.1.0.9-e2ef6e39c0da729a67d19f4c6af9f657
     ghc-syb-utils-0.2.3-e762c220d86bac9001fe97a4dd0b5d58
-    haskell-src-exts-1.17.1-7afd8d2f109e171c19a1cb4891217e0d
-    hlint-1.9.28-ea3d8590f6f10449340f771caa0b730b
+    haskell-src-exts-1.17.1-3d12ae784d636e2d6ddab796cfe281a8
+    hlint-1.9.31-c6f35c8d90bdf7dd49a61b0973fa4893
     monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
-    monad-journal-0.7.1-821bbaf50681c3e04fb012872c12c421
+    monad-journal-0.7.1-739d84421c9ca464fb6d425a63272956
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
     old-time-1.1.0.3-91625432bd7c61d043f9b743fb82dcf7
     pipes-4.1.8-48aeb04c3fec70e47e537a12d228def1
